==> markdown2confluence-1.1.1.tgz: package/index.js <==
var marked = require('marked')
var inlineLexer = marked.inlineLexer

module.exports = exports = markdown2confluence

// https://roundcorner.atlassian.net/secure/WikiRendererHelpAction.jspa?section=all
// https://confluence.atlassian.com/display/DOC/Confluence+Wiki+Markup
// http://blogs.atlassian.com/2011/11/why-we-removed-wiki-markup-editor-in-confluence-4/

function extend() {
    var len = arguments.length
    var target = arguments[0] || {}
    var i = 1, obj
    for (; i < len; i++) {
        obj = arguments[i]
        if (obj && 'object' == typeof obj) {
            for (var k in obj) {
                target[k] = obj[k]
            }
        }
    }
    return target
}

function Renderer() {}

var rawRenderer = marked.Renderer

var langArr = 'actionscript3 bash csharp coldfusion cpp css delphi diff erlang groovy java javafx javascript perl php none powershell python ruby scala sql vb html/xml'.split(/\s+/)
var langMap = {}
for (var i = 0, x; x = langArr[i++];) { 
    langMap[x] = x
}

extend(Renderer.prototype, rawRenderer.prototype, {
      paragraph: function(text) {
        return text + '\n\n'
    }
    , html: function(html) {
        return html
    }
    , heading: function(text, level, raw) {
        return 'h' + level + '. ' + text + '\n\n'
    }
    , strong: function(text) {
        return '*' + text + '*'
    }
    , em: function(text) {
        return '_' + text + '_'
    }
    , del: function(text) {
        return '-' + text + '-'
    }
    , codespan: function(text) {
        return '{{' + text + '}}'
    }
    , blockquote: function(quote) {
        return '{quote}' + quote + '{quote}'
    }
    , br: function() {
        return '\n'
    }
    , hr: function() {
        return '----'
    }
    , link: function(href, title, text) {
        var arr = [href]
        if (title) {
            arr.unshift(title)
        }
        return '[' + arr.join('|') + ']'
    }
    , list: function(body, ordered) {
        return body + '\n'
    }
    , listitem: function(body, ordered) {
        var type = ordered ? '#' : '*'
        return type + ' ' + body + '\n'
    }
    , image: function(href, title, text) {
        return '!' + href
    }
    , table: function(header, body) {
        return header + body + '\n'
    }
    , tablerow: function(content, flags) {
        return content + '\n'
    }
    , tablecell: function(content, flags) {
        var type = flags.header ? '||' : '|'
        return type + content
    }
    , code: function(code, lang) {
        lang = langMap[lang] || langMap[langArr[0]]
        return '{code:' + lang + '}\n' + code + '\n{code}\n\n'
    }
})

var renderer = new Renderer()

function markdown2confluence(markdown) {
    return marked(markdown, {renderer: renderer})
}

==> markdown2confluence-1.1.3.tgz: package/index.js <==
var marked = require('marked')
var inlineLexer = marked.inlineLexer

module.exports = exports = markdown2confluence

// https://roundcorner.atlassian.net/secure/WikiRendererHelpAction.jspa?section=all
// https://confluence.atlassian.com/display/DOC/Confluence+Wiki+Markup
// http://blogs.atlassian.com/2011/11/why-we-removed-wiki-markup-editor-in-confluence-4/

function extend() {
    var len = arguments.length
    var target = arguments[0] || {}
    var i = 1, obj
    for (; i < len; i++) {
        obj = arguments[i]
        if (obj && 'object' == typeof obj) {
            for (var k in obj) {
                target[k] = obj[k]
            }
        }
    }
    return target
}

function Renderer() {}

var rawRenderer = marked.Renderer

var langArr = 'actionscript3 bash csharp coldfusion cpp css delphi diff erlang groovy java javafx javascript perl php none powershell python ruby scala sql vb html/xml'.split(/\s+/)
var langMap = {}
for (var i = 0, x; x = langArr[i++];) { 
    langMap[x] = x
}

extend(Renderer.prototype, rawRenderer.prototype, {
      paragraph: function(text) {
        return text + '\n\n'
    }
    , html: function(html) {
        return html
    }
    , heading: function(text, level, raw) {
        return 'h' + level + '. ' + text + '\n\n'
    }
    , strong: function(text) {
        return '*' + text + '*'
    }
    , em: function(text) {
        return '_' + text + '_'
    }
    , del: function(text) {
        return '-' + text + '-'
    }
    , codespan: function(text) {
        return '{{' + text + '}}'
    }
    , blockquote: function(quote) {
        return '{quote}' + quote + '{quote}\n\n'
    }
    , br: function() {
        return '\n'
    }
    , hr: function() {
        return '----'
    }
    , link: function(href, title, text) {
        href = href.replace('&amp;', '&', 'g')
        var arr = [href]
        if (text) {
            arr.unshift(text)
        }
        return '[' + arr.join('|') + ']'
    }
    , list: function(body, ordered) {
        return body + '\n'
    }
    , listitem: function(body, ordered) {
        var type = ordered ? '#' : '*'
        return type + ' ' + body + '\n'
    }
    , image: function(href, title, text) {
        return '!' + href
    }
    , table: function(header, body) {
        return header + body + '\n'
    }
    , tablerow: function(content, flags) {
        return content + '\n'
    }
    , tablecell: function(content, flags) {
        var type = flags.header ? '||' : '|'
        return type + content
    }
    , code: function(code, lang) {
        lang = langMap[lang] || langMap[langArr[0]]
        return '{code:' + lang + '}\n' + code + '\n{code}\n\n'
    }
})

var renderer = new Renderer()

function markdown2confluence(markdown) {
    return marked(markdown, {renderer: renderer})
}
